@@ -1,30 +1,5 @@
-/* libmpdclient
-   (c) 2003-2019 The Music Player Daemon Project
-   This project's homepage is: http://www.musicpd.org
-
-   Redistribution and use in source and binary forms, with or without
-   modification, are permitted provided that the following conditions
-   are met:
-
-   - Redistributions of source code must retain the above copyright
-   notice, this list of conditions and the following disclaimer.
-
-   - Redistributions in binary form must reproduce the above copyright
-   notice, this list of conditions and the following disclaimer in the
-   documentation and/or other materials provided with the distribution.
-
-   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-   ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
-   A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR
-   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
-   EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
-   PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
-   PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
-   LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
-   NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
-   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-*/
+// SPDX-License-Identifier: BSD-2-Clause
+// Copyright The Music Player Daemon Project
 
 #include <mpd/playlist.h>
 #include <mpd/position.h>
@@ -35,6 +10,7 @@
 
 #include <limits.h>
 #include <stdio.h>
+#include <string.h>
 
 /* (bits+1)/3 (plus the sign character) */
 enum {
@@ -127,6 +103,23 @@ mpd_run_playlist_move(struct mpd_connection *connection, const char *name,
 		mpd_response_finish(connection);
 }
 
+bool
+mpd_send_playlist_move_range(struct mpd_connection *connection, const char *name,
+		       unsigned start, unsigned end, unsigned to)
+{
+	return mpd_send_s_range_to_u_command(connection, "playlistmove", name,
+				start, end, to);
+}
+
+bool
+mpd_run_playlist_move_range(struct mpd_connection *connection, const char *name,
+		       unsigned start, unsigned end, unsigned to)
+{
+	return mpd_run_check(connection) &&
+		mpd_send_playlist_move_range(connection, name, start, end, to) &&
+		mpd_response_finish(connection);
+}
+
 bool
 mpd_send_playlist_delete(struct mpd_connection *connection, const char *name,
 			 unsigned pos)
@@ -178,6 +171,53 @@ mpd_run_save(struct mpd_connection *connection, const char *name)
 		mpd_response_finish(connection);
 }
 
+enum mpd_queue_save_mode mpd_parse_queue_save_mode(const char *p)
+{
+	if (strcmp(p, "create") == 0)
+		return MPD_QUEUE_SAVE_MODE_CREATE;
+	else if (strcmp(p, "replace") == 0)
+		return MPD_QUEUE_SAVE_MODE_REPLACE;
+	else if (strcmp(p, "append") == 0)
+		return MPD_QUEUE_SAVE_MODE_APPEND;
+	else
+		return MPD_QUEUE_SAVE_MODE_UNKNOWN;
+}
+
+const char *
+mpd_lookup_queue_save_mode(enum mpd_queue_save_mode mode)
+{
+	switch (mode) {
+	case MPD_QUEUE_SAVE_MODE_CREATE:
+		return "create";
+	case MPD_QUEUE_SAVE_MODE_REPLACE:
+		return "replace";
+	case MPD_QUEUE_SAVE_MODE_APPEND:
+		return "append";
+	case MPD_QUEUE_SAVE_MODE_UNKNOWN:
+		return NULL;
+	}
+	return NULL;
+}
+
+bool
+mpd_send_save_queue(struct mpd_connection *connection, const char *name,
+		enum mpd_queue_save_mode mode)
+{
+	const char *mode_str = mpd_lookup_queue_save_mode(mode);
+	if (mode_str == NULL)
+		return false;
+	return mpd_send_command(connection, "save", name, mode_str, NULL);
+}
+
+bool
+mpd_run_save_queue(struct mpd_connection *connection, const char *name,
+		enum mpd_queue_save_mode mode)
+{
+	return mpd_run_check(connection) &&
+		mpd_send_save_queue(connection, name, mode) &&
+		mpd_response_finish(connection);
+}
+
 bool
 mpd_send_load(struct mpd_connection *connection, const char *name)
 {
