@@ -1,30 +1,5 @@
-/* libmpdclient
-   (c) 2003-2019 The Music Player Daemon Project
-   This project's homepage is: http://www.musicpd.org
-
-   Redistribution and use in source and binary forms, with or without
-   modification, are permitted provided that the following conditions
-   are met:
-
-   - Redistributions of source code must retain the above copyright
-   notice, this list of conditions and the following disclaimer.
-
-   - Redistributions in binary form must reproduce the above copyright
-   notice, this list of conditions and the following disclaimer in the
-   documentation and/or other materials provided with the distribution.
-
-   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-   ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
-   A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR
-   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
-   EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
-   PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
-   PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
-   LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
-   NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
-   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-*/
+// SPDX-License-Identifier: BSD-2-Clause
+// Copyright The Music Player Daemon Project
 
 #include <mpd/player.h>
 #include <mpd/send.h>
@@ -78,7 +53,7 @@ mpd_run_play(struct mpd_connection *connection)
 bool
 mpd_send_play_pos(struct mpd_connection *connection, unsigned song_pos)
 {
-	return mpd_send_int_command(connection, "play", song_pos);
+	return mpd_send_u_command(connection, "play", song_pos);
 }
 
 bool
@@ -92,7 +67,7 @@ mpd_run_play_pos(struct mpd_connection *connection, unsigned song_pos)
 bool
 mpd_send_play_id(struct mpd_connection *connection, unsigned song_id)
 {
-	return mpd_send_int_command(connection, "playid", song_id);
+	return mpd_send_u_command(connection, "playid", song_id);
 }
 
 bool
@@ -173,7 +148,7 @@ bool
 mpd_send_seek_pos(struct mpd_connection *connection,
 		 unsigned song_pos, unsigned t)
 {
-	return mpd_send_int2_command(connection, "seek", song_pos, t);
+	return mpd_send_u2_command(connection, "seek", song_pos, t);
 }
 
 bool
@@ -189,7 +164,7 @@ bool
 mpd_send_seek_id(struct mpd_connection *connection,
 		 unsigned song_id, unsigned t)
 {
-	return mpd_send_int2_command(connection, "seekid", song_id, t);
+	return mpd_send_u2_command(connection, "seekid", song_id, t);
 }
 
 bool
@@ -223,9 +198,9 @@ mpd_send_seek_current(struct mpd_connection *connection,
 {
 	char ts[32];
 	if (relative)
-		snprintf(ts, sizeof(ts), "%+.3f", t);
+		snprintf(ts, sizeof(ts), "%+.3f", (double)t);
 	else
-		snprintf(ts, sizeof(ts), "%.3f", t);
+		snprintf(ts, sizeof(ts), "%.3f", (double)t);
 
 	return mpd_send_command(connection, "seekcur", ts, NULL);
 }
@@ -267,6 +242,26 @@ mpd_run_random(struct mpd_connection *connection, bool mode)
 		mpd_response_finish(connection);
 }
 
+bool
+mpd_send_single_state(struct mpd_connection *connection,
+		      enum mpd_single_state state)
+{
+	const char *state_str = mpd_lookup_single_state(state);
+	if (state_str == NULL)
+		return false;
+
+	return mpd_send_command(connection, "single", state_str, NULL);
+}
+
+bool
+mpd_run_single_state(struct mpd_connection *connection,
+		      enum mpd_single_state state)
+{
+	return mpd_run_check(connection) &&
+		mpd_send_single_state(connection, state) &&
+		mpd_response_finish(connection);
+}
+
 bool
 mpd_send_single(struct mpd_connection *connection, bool mode)
 {
@@ -281,6 +276,26 @@ mpd_run_single(struct mpd_connection *connection, bool mode)
 		mpd_response_finish(connection);
 }
 
+bool
+mpd_send_consume_state(struct mpd_connection *connection,
+		      enum mpd_consume_state state)
+{
+	const char *state_str = mpd_lookup_consume_state(state);
+	if (state_str == NULL)
+		return false;
+
+	return mpd_send_command(connection, "consume", state_str, NULL);
+}
+
+bool
+mpd_run_consume_state(struct mpd_connection *connection,
+		      enum mpd_consume_state state)
+{
+	return mpd_run_check(connection) &&
+		mpd_send_consume_state(connection, state) &&
+		mpd_response_finish(connection);
+}
+
 bool
 mpd_send_consume(struct mpd_connection *connection, bool mode)
 {
@@ -298,7 +313,7 @@ mpd_run_consume(struct mpd_connection *connection, bool mode)
 bool
 mpd_send_crossfade(struct mpd_connection *connection, unsigned seconds)
 {
-	return mpd_send_int_command(connection, "crossfade", seconds);
+	return mpd_send_u_command(connection, "crossfade", seconds);
 }
 
 bool
