@@ -1,34 +1,5 @@
-/* libmpdclient
-   (c) 2003-2019 The Music Player Daemon Project
-   This project's homepage is: http://www.musicpd.org
-
-   Redistribution and use in source and binary forms, with or without
-   modification, are permitted provided that the following conditions
-   are met:
-
-   - Redistributions of source code must retain the above copyright
-   notice, this list of conditions and the following disclaimer.
-
-   - Redistributions in binary form must reproduce the above copyright
-   notice, this list of conditions and the following disclaimer in the
-   documentation and/or other materials provided with the distribution.
-
-   - Neither the name of the Music Player Daemon nor the names of its
-   contributors may be used to endorse or promote products derived from
-   this software without specific prior written permission.
-
-   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-   ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
-   A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR
-   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
-   EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
-   PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
-   PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
-   LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
-   NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
-   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-*/
+// SPDX-License-Identifier: BSD-3-Clause
+// Copyright The Music Player Daemon Project
 
 #include <mpd/tag.h>
 
@@ -68,11 +39,14 @@ static const char *const mpd_tag_type_names[MPD_TAG_COUNT] =
 	[MPD_TAG_WORK] = "Work",
 	[MPD_TAG_CONDUCTOR] = "Conductor",
 
-    [MPD_TAG_COMPOSER_SORT] = "ComposerSort",
-    [MPD_TAG_ENSEMBLE] = "Ensemble",
-    [MPD_TAG_MOVEMENT] = "Movement",
-    [MPD_TAG_MOVEMENTNUMBER] = "MovementNumber",
-    [MPD_TAG_LOCATION] = "Location",
+	[MPD_TAG_COMPOSER_SORT] = "ComposerSort",
+	[MPD_TAG_ENSEMBLE] = "Ensemble",
+	[MPD_TAG_MOVEMENT] = "Movement",
+	[MPD_TAG_MOVEMENTNUMBER] = "MovementNumber",
+	[MPD_TAG_LOCATION] = "Location",
+	[MPD_TAG_MOOD] = "Mood",
+	[MPD_TAG_TITLE_SORT] = "TitleSort",
+	[MPD_TAG_MUSICBRAINZ_RELEASEGROUPID] = "MUSICBRAINZ_RELEASEGROUPID",
 };
 
 const char *
